@@ -247,7 +247,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
 
     @Override
     public int onStartCommand(Intent intent, int flags, int startId) {
-        if (AndroidUtil.isOOrLater && !VLCApplication.isForeground()) forceForeground();
+        if (AndroidUtil.isOOrLater && !mIsForeground && !VLCApplication.isForeground()) forceForeground();
         if (intent == null) return START_NOT_STICKY;
         final String action = intent.getAction();
         if (Intent.ACTION_MEDIA_BUTTON.equals(action)) {
@@ -974,12 +974,12 @@ public class PlaybackService extends MediaBrowserServiceCompat{
 
         @Override
         public void onSkipToPrevious() {
-            previous(false);
+            previous(true);
         }
 
         @Override
         public void onSeekTo(long pos) {
-            seek(pos);
+            seek(pos < 0 ? getTime()+pos : pos);
         }
 
         @Override
@@ -1079,7 +1079,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
         if (repeatType != Constants.REPEAT_NONE || hasPrevious() || isSeekable())
             actions |= PlaybackStateCompat.ACTION_SKIP_TO_PREVIOUS;
         if (isSeekable())
-            actions |= PlaybackStateCompat.ACTION_FAST_FORWARD | PlaybackStateCompat.ACTION_REWIND;
+            actions |= PlaybackStateCompat.ACTION_FAST_FORWARD | PlaybackStateCompat.ACTION_REWIND | PlaybackStateCompat.ACTION_SEEK_TO;
         actions |= PlaybackStateCompat.ACTION_SKIP_TO_QUEUE_ITEM;
         pscb.setActions(actions);
         final int repeatResId = repeatType == Constants.REPEAT_ALL ? R.drawable.ic_auto_repeat_pressed : repeatType == Constants.REPEAT_ONE ? R.drawable.ic_auto_repeat_one_pressed : R.drawable.ic_auto_repeat_normal;
