@@ -244,14 +244,15 @@ class AudioPlayer : PlaybackServiceFragment(), PlaybackService.Callback, Playlis
         if (mService === null) return
         val time = mService.time
         val length = mService.length
+        val timeText = Tools.millisToString((if (mShowRemainingTime) time - length else time))
 
-        mBinding.headerTime.text = Tools.millisToString(time)
+        mBinding.headerTime.text = timeText
         mBinding.length.text = Tools.millisToString(length)
         mBinding.timeline.max = length.toInt()
         mBinding.progressBar.max = length.toInt()
 
         if (!mPreviewingSeek) {
-            mBinding.time.text = Tools.millisToString((if (mShowRemainingTime) time - length else time))
+            mBinding.time.text = timeText
             mBinding.timeline.progress = time.toInt()
             mBinding.progressBar.progress = time.toInt()
         }
@@ -262,7 +263,6 @@ class AudioPlayer : PlaybackServiceFragment(), PlaybackService.Callback, Playlis
     override fun onMediaPlayerEvent(event: MediaPlayer.Event) {
         when (event.type) {
             MediaPlayer.Event.Opening -> hideSearchField()
-            MediaPlayer.Event.Stopped -> hide()
         }
     }
 
@@ -313,7 +313,6 @@ class AudioPlayer : PlaybackServiceFragment(), PlaybackService.Callback, Playlis
 
     fun onTimeLabelClick(view: View) {
         mShowRemainingTime = !mShowRemainingTime
-        update()
     }
 
     fun onPlayPauseClick(view: View) {
