@@ -19,7 +19,7 @@ public class MedialibraryUtils {
     }
 
     public static void addDir(final String path) {
-        Intent intent = new Intent(Constants.ACTION_DISCOVER, null, VLCApplication.getAppContext(), MediaParsingService.class);
+        final Intent intent = new Intent(Constants.ACTION_DISCOVER, null, VLCApplication.getAppContext(), MediaParsingService.class);
         intent.putExtra(Constants.EXTRA_PATH, path);
         VLCApplication.getAppContext().startService(intent);
     }
