@@ -49,7 +49,6 @@ import android.support.v17.leanback.widget.RowPresenter;
 import android.support.v4.content.ContextCompat;
 import android.support.v4.content.LocalBroadcastManager;
 import android.support.v4.util.SimpleArrayMap;
-import android.support.v7.widget.RecyclerView;
 import android.view.KeyEvent;
 import android.view.View;
 import android.view.View.OnClickListener;
@@ -57,7 +56,6 @@ import android.widget.ProgressBar;
 
 import org.videolan.libvlc.Media;
 import org.videolan.libvlc.MediaPlayer;
-import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.medialibrary.Medialibrary;
 import org.videolan.medialibrary.Tools;
 import org.videolan.medialibrary.interfaces.MediaUpdatedCb;
@@ -160,6 +158,9 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         mBackgroundManager = BackgroundManager.getInstance(this);
         mBackgroundManager.setAutoReleaseOnStop(false);
         TvUtil.clearBackground(mBackgroundManager);
+        // add a listener for selected items
+        mBrowseFragment.setOnItemViewClickedListener(MainTvActivity.this);
+        mBrowseFragment.setOnItemViewSelectedListener(MainTvActivity.this);
     }
 
     @Override
@@ -171,7 +172,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
          * skip browser and show directly Audio Player if a song is playing
          */
         if (!mMediaLibrary.isWorking() && (mRowsAdapter == null || mRowsAdapter.size() == 0) && Permissions.canReadStorage(this))
-            update();
+            updateView();
         else {
             updateBrowsers();
             updateNowPlayingCard();
@@ -183,7 +184,21 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
                         VLCApplication.runOnMainThread(new Runnable() {
                             @Override
                             public void run() {
-                                updateHistory(history);
+                                final ListRow hist = updateHistory(history);
+                                if (hist != null) mRowsAdapter.add(Math.min(2, mRowsAdapter.size()), hist);
+                                else removeHistory();
+                            }
+
+                            private void removeHistory() {
+                                int position = -1;
+                                for (int i = 0; i < mRowsAdapter.size(); ++i) {
+                                    if (((ListRow)mRowsAdapter.get(i)).getHeaderItem().getId() == HEADER_HISTORY) {
+                                        position = i;
+                                        break;
+                                    }
+                                }
+                                if (position != -1) mRowsAdapter.removeItems(position, 1);
+                                mHistoryAdapter = null;
                             }
                         });
                     }
@@ -208,7 +223,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
     @Override
     protected void onStop() {
         super.onStop();
-        if (AndroidDevices.isAndroidTv && !AndroidUtil.isOOrLater) startService(new Intent(this, RecommendationsService.class));
+        if (AndroidDevices.isAndroidTv) startService(new Intent(this, RecommendationsService.class));
         TvUtil.releaseBackgroundManager(mBackgroundManager);
     }
 
@@ -263,7 +278,12 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         return super.onKeyDown(keyCode, event);
     }
 
+    @Override
     public void update() {
+        updateNowPlayingCard();
+    }
+
+    public void updateView() {
         if (mUpdateTask == null || mUpdateTask.getStatus() == AsyncTask.Status.FINISHED) {
             mUpdateTask = new AsyncUpdate();
             mUpdateTask.execute();
@@ -343,7 +363,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
 
     @Override
     protected void onParsingServiceFinished() {
-        update();
+        updateView();
     }
 
     private static final int SHOW_LOADING = 0;
@@ -394,15 +414,18 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         protected void onPostExecute(Void result) {
             mHandler.sendEmptyMessage(HIDE_LOADING);
             if (!isVisible()) return;
-            if (mRowsAdapter != null) mRowsAdapter.clear();
-            else mRowsAdapter = new ArrayObjectAdapter(new ListRowPresenter());
+            if (mRowsAdapter == null) {
+                mRowsAdapter = new ArrayObjectAdapter(new ListRowPresenter());
+                mBrowseFragment.setAdapter(mRowsAdapter);
+            }
+            final ArrayObjectAdapter adapter = new ArrayObjectAdapter(new ListRowPresenter());
             mHistoryIndex.clear();
             //Video Section
             mVideoIndex.clear();
             mVideoAdapter = new ArrayObjectAdapter(new CardPresenter(mContext));
             final HeaderItem videoHeader = new HeaderItem(HEADER_VIDEO, getString(R.string.video));
             // Empty item to launch grid activity
-            mVideoAdapter.add(new CardPresenter.SimpleCard(0, "All videos", videoList.length+" "+getString(R.string.videos), R.drawable.ic_video_collection_big));
+            mVideoAdapter.add(new CardPresenter.SimpleCard(0, getString(R.string.videos_all), getResources().getQuantityString(R.plurals.videos_quantity, videoList.length, videoList.length), R.drawable.ic_video_collection_big));
             // Update video section
             if (!Tools.isArrayEmpty(videoList)) {
                 final int size = Math.min(NUM_ITEMS_PREVIEW, videoList.length);
@@ -412,7 +435,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
                     mVideoIndex.put(videoList[i].getLocation(), i);
                 }
             }
-            mRowsAdapter.add(new ListRow(videoHeader, mVideoAdapter));
+            adapter.add(new ListRow(videoHeader, mVideoAdapter));
 
             //Music sections
             mCategoriesAdapter = new ArrayObjectAdapter(new CardPresenter(mContext));
@@ -422,16 +445,19 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
             mCategoriesAdapter.add(new CardPresenter.SimpleCard(MusicFragment.CATEGORY_ALBUMS, getString(R.string.albums), R.drawable.ic_album_big));
             mCategoriesAdapter.add(new CardPresenter.SimpleCard(MusicFragment.CATEGORY_GENRES, getString(R.string.genres), R.drawable.ic_genre_big));
             mCategoriesAdapter.add(new CardPresenter.SimpleCard(MusicFragment.CATEGORY_SONGS, getString(R.string.songs), R.drawable.ic_song_big));
-            mRowsAdapter.add(new ListRow(musicHeader, mCategoriesAdapter));
+            adapter.add(new ListRow(musicHeader, mCategoriesAdapter));
 
             //History
-            if (showHistory && !Tools.isArrayEmpty(history)) updateHistory(history);
+            if (showHistory && !Tools.isArrayEmpty(history)) {
+                final ListRow hist = updateHistory(history);
+                if (hist != null) adapter.add(hist);
+            }
 
             //Browser section
             mBrowserAdapter = new ArrayObjectAdapter(new CardPresenter(mContext));
             final HeaderItem browserHeader = new HeaderItem(HEADER_NETWORK, getString(R.string.browsing));
             updateBrowsers();
-            mRowsAdapter.add(new ListRow(browserHeader, mBrowserAdapter));
+            adapter.add(new ListRow(browserHeader, mBrowserAdapter));
 
             mOtherAdapter = new ArrayObjectAdapter(new CardPresenter(mContext));
             final HeaderItem miscHeader = new HeaderItem(HEADER_MISC, getString(R.string.other));
@@ -439,33 +465,41 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
             mOtherAdapter.add(new CardPresenter.SimpleCard(ID_SETTINGS, getString(R.string.preferences), R.drawable.ic_menu_preferences_big));
             mOtherAdapter.add(new CardPresenter.SimpleCard(ID_ABOUT, getString(R.string.about), getString(R.string.app_name_full)+" "+ BuildConfig.VERSION_NAME, R.drawable.ic_default_cone));
             mOtherAdapter.add(new CardPresenter.SimpleCard(ID_LICENCE, getString(R.string.licence), R.drawable.ic_default_cone));
-            mRowsAdapter.add(new ListRow(miscHeader, mOtherAdapter));
-            if (mBrowseFragment.getSelectedPosition() >= mRowsAdapter.size()) mBrowseFragment.setSelectedPosition(RecyclerView.NO_POSITION);
-            mBrowseFragment.setAdapter(mRowsAdapter);
-            mBrowseFragment.setSelectedPosition(Math.min(mBrowseFragment.getSelectedPosition(), mRowsAdapter.size()-1));
+            adapter.add(new ListRow(miscHeader, mOtherAdapter));
 
-            // add a listener for selected items
-            mBrowseFragment.setOnItemViewClickedListener(MainTvActivity.this);
-            mBrowseFragment.setOnItemViewSelectedListener(MainTvActivity.this);
+            if (mBrowseFragment.getSelectedPosition() < adapter.size()) {
+                mRowsAdapter = adapter;
+                mBrowseFragment.setAdapter(mRowsAdapter);
+            } else { // set selection is asynchronous, we neeed a delay
+                mBrowseFragment.setSelectedPosition(0);
+                mHandler.post(new Runnable() {
+                    @Override
+                    public void run() {
+                        mRowsAdapter = adapter;
+                        mBrowseFragment.setAdapter(mRowsAdapter);
+                    }
+                });
+            }
         }
     }
 
     @MainThread
-    private synchronized void updateHistory(MediaWrapper[] history) {
-        if (history == null || mRowsAdapter == null) return;
+    private synchronized ListRow updateHistory(MediaWrapper[] history) {
+        if (history == null || mRowsAdapter == null) return null;
         final boolean createAdapter = mHistoryAdapter == null;
         if (createAdapter) mHistoryAdapter = new ArrayObjectAdapter(new CardPresenter(mContext));
         else mHistoryAdapter.clear();
-        if (!mSettings.getBoolean(PreferencesFragment.PLAYBACK_HISTORY, true)) return;
+        if (!mSettings.getBoolean(PreferencesFragment.PLAYBACK_HISTORY, true)) return null;
         for (int i = 0; i < history.length; ++i) {
-            final MediaWrapper item = history[i];
+            final MediaWrapper item = mMediaLibrary.findMedia(history[i]);
             mHistoryAdapter.add(item);
             mHistoryIndex.put(item.getLocation(), i);
         }
         if (createAdapter) {
             final HeaderItem historyHeader = new HeaderItem(HEADER_HISTORY, getString(R.string.history));
-            mRowsAdapter.add(Math.min(2, mRowsAdapter.size()), new ListRow(historyHeader, mHistoryAdapter));
+            return new ListRow(historyHeader, mHistoryAdapter);
         }
+        return null;
     }
 
     private void updateBrowsers() {
@@ -511,17 +545,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
 
     @Override
     public
-    void onMediaPlayerEvent(MediaPlayer.Event event){
-        switch (event.type) {
-            case MediaPlayer.Event.Opening:
-                updateNowPlayingCard();
-                break;
-            case MediaPlayer.Event.Stopped:
-                if (mNowPlayingCard != null)
-                    mCategoriesAdapter.remove(mNowPlayingCard);
-                break;
-        }
-    }
+    void onMediaPlayerEvent(MediaPlayer.Event event) {}
 
     public void updateNowPlayingCard () {
         if (mService == null) return;
@@ -555,7 +579,6 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
                     });
                 }
             });
-
         }
     }
 
@@ -569,7 +592,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
             public void onReceive(Context context, Intent intent) {
                 LocalBroadcastManager.getInstance(MainTvActivity.this).unregisterReceiver(this);
                 setmedialibraryListeners();
-                update();
+                updateView();
             }
         };
         LocalBroadcastManager.getInstance(this).registerReceiver(libraryReadyReceiver, new IntentFilter(VLCApplication.ACTION_MEDIALIBRARY_READY));
