@@ -21,10 +21,12 @@
  */
 
 package org.videolan.vlc.gui.tv.preferences;
+
 import android.annotation.TargetApi;
 import android.content.SharedPreferences;
 import android.os.Build;
 import android.os.Bundle;
+import android.support.v7.preference.CheckBoxPreference;
 
 import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.libvlc.util.HWDecoderUtil;
@@ -61,6 +63,14 @@ public class PreferencesAudio extends BasePreferenceFragment implements SharedPr
             /* no AudioOutput choice */
             findPreference("aout").setVisible(false);
         }
+        updatePassThroughSummary();
+        final boolean opensles = "1".equals(getPreferenceManager().getSharedPreferences().getString("aout", "0"));
+        if (opensles) findPreference("audio_digital_output").setVisible(false);
+    }
+
+    private void updatePassThroughSummary() {
+        final boolean pt = getPreferenceManager().getSharedPreferences().getBoolean("audio_digital_output", false);
+        findPreference("audio_digital_output").setSummary(pt ? R.string.audio_digital_output_enabled : R.string.audio_digital_output_disabled);
     }
 
     @Override
@@ -75,8 +85,10 @@ public class PreferencesAudio extends BasePreferenceFragment implements SharedPr
         switch (key){
             case "aout":
                 VLCInstance.restart();
-                if (getActivity() != null )
-                    ((PreferencesActivity)getActivity()).restartMediaPlayer();
+                if (getActivity() != null ) ((PreferencesActivity)getActivity()).restartMediaPlayer();
+                final boolean opensles = "1".equals(getPreferenceManager().getSharedPreferences().getString("aout", "0"));
+                if (opensles) ((CheckBoxPreference)findPreference("audio_digital_output")).setChecked(false);
+                findPreference("audio_digital_output").setVisible(!opensles);
         }
     }
 }
\ No newline at end of file
