@@ -78,7 +78,7 @@ public class SubtitlesDownloader {
     private static final int DIALOG_UPDATE_MSG = 4;
     private static final String TAG = "VLC/SubtitlesDownloader";
 
-    private static final String OpenSubtitlesAPIUrl = "http://api.opensubtitles.org/xml-rpc";
+    private static final String OpenSubtitlesAPIUrl = "https://api.opensubtitles.org/xml-rpc";
     private static final String HTTP_USER_AGENT = "VLSub";
     private static final String USER_AGENT = "VLSub 0.9";
     private static final File SUBTITLES_DIRECTORY = new File(VLCApplication.getAppContext().getExternalFilesDir(null), "subs");
@@ -327,14 +327,17 @@ public class SubtitlesDownloader {
         if (mToken == null || path == null) return;
         final StringBuilder sb = new StringBuilder();
         final String name = fileName.lastIndexOf('.') > 0 ? fileName.substring(0, fileName.lastIndexOf('.')) : fileName;
-        sb.append(SUBTITLES_DIRECTORY.getPath()).append('/').append(name).append('.').append(language).append('.').append(subFormat);
+        sb.append(SUBTITLES_DIRECTORY.getPath())
+                .append('/').append(name.replace("/", ""))
+                .append('.').append(language.replace("/", ""))
+                .append('.').append(subFormat.replace("/", ""));
         final String srtUrl = sb.toString();
         FileOutputStream f = null;
         GZIPInputStream gzIS = null;
         URL url;
         HttpURLConnection urlConnection;
-        try {
-            url  = new URL(subUrl);
+        if (subUrl.startsWith("https")) try {
+            url = new URL(subUrl);
             urlConnection = (HttpURLConnection) url.openConnection();
             // We get the first matching subtitle
             f = new FileOutputStream(new File(srtUrl));
